@@ -1,8 +1,8 @@
 """Asynchronous Python Reddit API Wrapper.
 
 Async PRAW, an abbreviation for "Asynchronous Python Reddit API Wrapper", is a python
-package that allows for simple access to reddit's API. Async PRAW aims to be as easy to
-use as possible and is designed to follow all of reddit's API rules. You have to give a
+package that allows for simple access to Reddit's API. Async PRAW aims to be as easy to
+use as possible and is designed to follow all of Reddit's API rules. You have to give an
 useragent, everything else is handled by Async PRAW so you needn't worry about violating
 them.
 
