@@ -9,6 +9,7 @@ from asyncprawcore import (
 )
 
 from ..exceptions import InvalidImplicitAuth, MissingRequiredAttributeException
+from ..util import _deprecate_args
 from .base import AsyncPRAWBase
 
 
@@ -60,7 +61,8 @@ class Auth(AsyncPRAWBase):
         self._reddit._core = self._reddit._authorized_core = authorized_session
         return authorizer.refresh_token
 
-    def implicit(self, access_token: str, expires_in: int, scope: str) -> None:
+    @_deprecate_args("access_token", "expires_in", "scope")
+    def implicit(self, *, access_token: str, expires_in: int, scope: str) -> None:
         """Set the active authorization to be an implicit authorization.
 
         :param access_token: The access_token obtained from Reddit's callback.
@@ -95,28 +97,30 @@ class Auth(AsyncPRAWBase):
             await authorizer.refresh()
         return authorizer.scopes
 
+    @_deprecate_args("scopes", "state", "duration", "implicit")
     def url(
         self,
-        scopes: List[str],
-        state: str,
+        *,
         duration: str = "permanent",
         implicit: bool = False,
+        scopes: List[str],
+        state: str,
     ) -> str:
         """Return the URL used out-of-band to grant access to your application.
 
+        :param duration: Either ``"permanent"`` or ``"temporary"`` (default:
+            ``"permanent"``). ``"temporary"`` authorizations generate access tokens that
+            last only 1 hour. ``"permanent"`` authorizations additionally ``permanent``
+            authorizations additionally generate a refresh token that expires 1 year
+            after the last use and can be used indefinitelyto generate new hour-long
+            access tokens. This value is ignored when ``implicit=True``.
+        :param implicit: For **installed** applications, this value can be set to use
+            the implicit, rather than the code flow. When ``True``, the ``duration``
+            argument has no effect as only temporary tokens can be retrieved.
         :param scopes: A list of OAuth scopes to request authorization for.
         :param state: A string that will be reflected in the callback to
             ``redirect_uri``. This value should be temporarily unique to the client for
             whom the URL was generated for.
-        :param duration: Either ``permanent`` or ``temporary`` (default: permanent).
-            ``temporary`` authorizations generate access tokens that last only 1 hour.
-            ``permanent`` authorizations additionally ``permanent`` authorizations
-            additionally generate a refresh token that expires 1 year after the last use
-            and can be used indefinitelyto generate new hour-long access tokens. This
-            value is ignored when ``implicit=True``.
-        :param implicit: For **installed** applications, this value can be set to use
-            the implicit, rather than the code flow. When True, the ``duration``
-            argument has no effect as only temporary tokens can be retrieved.
 
         """
         authenticator = self._reddit._read_only_core._authorizer._authenticator
