@@ -10,17 +10,17 @@ class AsyncPRAWBase:
     """Superclass for all models in Async PRAW."""
 
     @staticmethod
-    def _safely_add_arguments(argument_dict, key, **new_arguments):
-        """Replace argument_dict[key] with a deepcopy and update.
+    def _safely_add_arguments(*, arguments, key, **new_arguments):
+        """Replace arguments[key] with a deepcopy and update.
 
         This method is often called when new parameters need to be added to a request.
         By calling this method and adding the new or updated parameters we can insure we
         don't modify the dictionary passed in by the caller.
 
         """
-        value = deepcopy(argument_dict[key]) if key in argument_dict else {}
+        value = deepcopy(arguments[key]) if key in arguments else {}
         value.update(new_arguments)
-        argument_dict[key] = value
+        arguments[key] = value
 
     @classmethod
     def parse(cls, data: Dict[str, Any], reddit: "asyncpraw.Reddit") -> Any:
@@ -33,7 +33,7 @@ class AsyncPRAWBase:
         return cls(reddit, _data=data)
 
     def __init__(self, reddit: "asyncpraw.Reddit", _data: Optional[Dict[str, Any]]):
-        """Initialize a PRAWModel instance.
+        """Initialize a :class:`.AsyncPRAWBase` instance.
 
         :param reddit: An instance of :class:`.Reddit`.
 
