@@ -1,10 +1,11 @@
-"""Provide CommentForest for Submission comments."""
+"""Provide CommentForest for submission comments."""
 import inspect
 from heapq import heappop, heappush
 from typing import TYPE_CHECKING, Any, AsyncIterator, Coroutine, List, Optional, Union
 from warnings import warn
 
 from ..exceptions import DuplicateReplaceException
+from ..util import _deprecate_args
 from .reddit.more import MoreComments
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -19,8 +20,8 @@ class CommentForest:
     """
 
     @staticmethod
-    def _gather_more_comments(tree, parent_tree=None):
-        """Return a list of MoreComments objects obtained from tree."""
+    def _gather_more_comments(tree, *, parent_tree=None):
+        """Return a list of :class:`.MoreComments` objects obtained from tree."""
         more_comments = []
         queue = [(None, x) for x in tree]
         while queue:
@@ -98,11 +99,12 @@ class CommentForest:
         submission: "asyncpraw.models.Submission",
         comments: Optional[List["asyncpraw.models.Comment"]] = None,
     ):
-        """Initialize a CommentForest instance.
+        """Initialize a :class:`.CommentForest` instance.
 
         :param submission: An instance of :class:`.Submission` that is the parent of the
             comments.
-        :param comments: Initialize the Forest with a list of comments (default: None).
+        :param comments: Initialize the Forest with a list of comments (default:
+            ``None``).
 
         """
         self._comments = comments
@@ -155,7 +157,7 @@ class CommentForest:
             if not isinstance(comment, MoreComments):
                 queue.extend(comment.replies)
         # check if this got called with await
-        # I'm so sorry this really gross
+        # I'm so sorry this is really gross
         if any(
             [
                 "await" in context
@@ -177,19 +179,20 @@ class CommentForest:
             return async_func()
         return comments
 
+    @_deprecate_args("limit", "threshold")
     async def replace_more(
-        self, limit: int = 32, threshold: int = 0
+        self, *, limit: int = 32, threshold: int = 0
     ) -> List["asyncpraw.models.MoreComments"]:
-        """Update the comment forest by resolving instances of MoreComments.
+        """Update the comment forest by resolving instances of :class:`.MoreComments`.
 
         :param limit: The maximum number of :class:`.MoreComments` instances to replace.
             Each replacement requires 1 API request. Set to ``None`` to have no limit,
             or to ``0`` to remove all :class:`.MoreComments` instances without
-            additional requests (default: 32).
+            additional requests (default: ``32``).
         :param threshold: The minimum number of children comments a
             :class:`.MoreComments` instance must have in order to be replaced.
             :class:`.MoreComments` instances that represent "continue this thread" links
-            unfortunately appear to have 0 children. (default: 0).
+            unfortunately appear to have 0 children (default: ``0``).
 
         :returns: A list of :class:`.MoreComments` instances that were not replaced.
 
@@ -251,7 +254,9 @@ class CommentForest:
                 remaining -= 1
 
             # Add new MoreComment objects to the heap of more_comments
-            for more in self._gather_more_comments(new_comments, self._comments):
+            for more in self._gather_more_comments(
+                new_comments, parent_tree=self._comments
+            ):
                 more.submission = self._submission
                 heappush(more_comments, more)
             # Insert all items into the tree
