@@ -13,7 +13,7 @@ class Front(SubredditListingMixin):
     """Front is a Listing class that represents the front page."""
 
     def __init__(self, reddit: "asyncpraw.Reddit"):
-        """Initialize a Front instance."""
+        """Initialize a :class:`.Front` instance."""
         super().__init__(reddit, _data=None)
         self._path = "/"
 
