@@ -3,6 +3,7 @@ from json import dumps
 from typing import TYPE_CHECKING, AsyncGenerator, List, Optional, Union
 
 from ..const import API_PATH
+from ..util import _deprecate_args
 from .base import AsyncPRAWBase
 from .reddit.draft import Draft
 from .reddit.live import LiveThread
@@ -13,17 +14,17 @@ if TYPE_CHECKING:  # pragma: no cover
 
 
 class DraftHelper(AsyncPRAWBase):
-    r"""Provide a set of functions to interact with :class:`Draft` instances.
+    r"""Provide a set of functions to interact with :class:`.Draft` instances.
 
     .. note::
 
         The methods provided by this class will only work on the currently authenticated
-        user's :class:`Draft`\ s.
+        user's :class:`.Draft`\ s.
 
     """
 
     async def __call__(
-        self, *, draft_id: Optional[str] = None, fetch: bool = True
+        self, draft_id: Optional[str] = None, fetch: bool = True
     ) -> Union[List["asyncpraw.models.Draft"], "asyncpraw.models.Draft"]:
         """Return a list of :class:`.Draft` instances.
 
@@ -40,7 +41,7 @@ class DraftHelper(AsyncPRAWBase):
         .. code-block:: python
 
             draft_id = "124862bc-e1e9-11eb-aa4f-e68667a77cbb"
-            draft = await reddit.drafts(draft_id=draft_id)
+            draft = await reddit.drafts(draft_id)
             print(draft)
 
         """
@@ -148,12 +149,12 @@ class DraftHelper(AsyncPRAWBase):
 
 
 class LiveHelper(AsyncPRAWBase):
-    """Provide a set of functions to interact with LiveThreads."""
+    r"""Provide a set of functions to interact with :class:`.LiveThread`\ s."""
 
     async def __call__(
         self, id: str, fetch: bool = False
     ) -> "asyncpraw.models.LiveThread":  # pylint: disable=invalid-name,redefined-builtin
-        """Return a new instance of :class:`~.LiveThread`.
+        """Return a new instance of :class:`.LiveThread`.
 
         This method is intended to be used as:
 
@@ -170,7 +171,8 @@ class LiveHelper(AsyncPRAWBase):
             await livethread.close()
 
         :param id: A live thread ID, e.g., ``ukaeu1ik4sw5``.
-        :param fetch: Determines if Async PRAW will fetch the object (default: False).
+        :param fetch: Determines if Async PRAW will fetch the object (default:
+            ``False``).
 
         """
         live_thread = LiveThread(self._reddit, id=id)
@@ -222,23 +224,25 @@ class LiveHelper(AsyncPRAWBase):
 
         return generator()
 
+    @_deprecate_args("title", "description", "nsfw", "resources")
     async def create(
         self,
         title: str,
+        *,
         description: Optional[str] = None,
         nsfw: bool = False,
         resources: str = None,
     ) -> "asyncpraw.models.LiveThread":
-        """Create a new LiveThread.
+        """Create a new :class:`.LiveThread`.
 
-        :param title: The title of the new LiveThread.
-        :param description: (Optional) The new LiveThread's description.
-        :param nsfw: (boolean) Indicate whether this thread is not safe for work
-            (default: False).
-        :param resources: (Optional) Markdown formatted information that is useful for
-            the LiveThread.
+        :param title: The title of the new :class:`.LiveThread`.
+        :param description: The new :class:`.LiveThread`'s description.
+        :param nsfw: Indicate whether this thread is not safe for work (default:
+            ``False``).
+        :param resources: Markdown formatted information that is useful for the
+            :class:`.LiveThread`.
 
-        :returns: The new LiveThread object.
+        :returns: The new :class`.LiveThread` object.
 
         """
         return await self._reddit.post(
@@ -268,29 +272,33 @@ class LiveHelper(AsyncPRAWBase):
 
 
 class MultiredditHelper(AsyncPRAWBase):
-    """Provide a set of functions to interact with Multireddits."""
+    """Provide a set of functions to interact with multireddits."""
 
+    @_deprecate_args("redditor", "name")
     async def __call__(
         self,
-        redditor: Union[str, "asyncpraw.models.Redditor"],
+        *,
         name: str,
+        redditor: Union[str, "asyncpraw.models.Redditor"],
         fetch: bool = False,
     ) -> "asyncpraw.models.Multireddit":
-        """Return an instance of :class:`~.Multireddit`.
+        """Return a lazy instance of :class:`.Multireddit`.
 
         If you need the object fetched right away (e.g., to access an attribute) you can
         do:
 
         .. code-block:: python
 
-            multireddit = await reddit.multireddit("redditor", "multi", fetch=True)
+            multireddit = await reddit.multireddit(redditor="redditor", name="multi", fetch=True)
             async for comment in multireddit.comments(limit=25):
                 print(comment.author)
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
-            instance who owns the multireddit.
         :param name: The name of the multireddit.
-        :param fetch: Determines if Async PRAW will fetch the object (default: False).
+        :param redditor: A redditor name or :class:`.Redditor` instance who owns the
+            multireddit.
+        :param name: The name of the multireddit.
+        :param fetch: Determines if Async PRAW will fetch the object (default:
+            ``False``).
 
         """
         path = f"/user/{redditor}/m/{name}"
@@ -299,36 +307,47 @@ class MultiredditHelper(AsyncPRAWBase):
             await multireddit._fetch()
         return multireddit
 
+    @_deprecate_args(
+        "display_name",
+        "subreddits",
+        "description_md",
+        "icon_name",
+        "key_color",
+        "visibility",
+        "weighting_scheme",
+    )
     async def create(
         self,
-        display_name: str,
-        subreddits: Union[str, "asyncpraw.models.Subreddit"],
+        *,
         description_md: Optional[str] = None,
+        display_name: str,
         icon_name: Optional[str] = None,
         key_color: Optional[str] = None,
+        subreddits: Union[str, "asyncpraw.models.Subreddit"],
         visibility: str = "private",
         weighting_scheme: str = "classic",
     ) -> "asyncpraw.models.Multireddit":
-        """Create a new multireddit.
+        """Create a new :class:`.Multireddit`.
 
         :param display_name: The display name for the new multireddit.
-        :param subreddits: Subreddits to add to the new multireddit.
-        :param description_md: (Optional) Description for the new multireddit, formatted
-            in markdown.
-        :param icon_name: (Optional) Can be one of: ``art and design``, ``ask``,
-            ``books``, ``business``, ``cars``, ``comics``, ``cute animals``, ``diy``,
-            ``entertainment``, ``food and drink``, ``funny``, ``games``, ``grooming``,
-            ``health``, ``life advice``, ``military``, ``models pinup``, ``music``,
-            ``news``, ``philosophy``, ``pictures and gifs``, ``science``, ``shopping``,
-            ``sports``, ``style``, ``tech``, ``travel``, ``unusual stories``, ``video``,
-            or ``None``.
-        :param key_color: (Optional) RGB hex color code of the form ``"#FFFFFF"``.
-        :param visibility: (Optional) Can be one of: ``hidden``, ``private``, ``public``
-            (default: private).
-        :param weighting_scheme: (Optional) Can be one of: ``classic``, ``fresh``
-            (default: classic).
+        :param subreddits: Subreddits to add to the new multireddit. Can be a list of
+            either :class:`.Subreddit` instances or subreddit display names.
+        :param description_md: Description for the new multireddit, formatted in
+            markdown.
+        :param icon_name: Can be one of: ``"art and design"``, ``"ask"``, ``"books"``,
+            ``"business"``, ``"cars"``, ``"comics"``, ``"cute animals"``, ``"diy"``,
+            ``"entertainment"``, ``"food and drink"``, ``"funny"``, ``"games"``,
+            ``"grooming"``, ``"health"``, ``"life advice"``, ``"military"``, ``"models
+            pinup"``, ``"music"``, ``"news"``, ``"philosophy"``, ``"pictures and
+            gifs"``, ``"science"``, ``"shopping"``, ``"sports"``, ``"style"``,
+            ``"tech"``, ``"travel"``, ``"unusual stories"``, ``"video"``, or ``None``.
+        :param key_color: RGB hex color code of the form ``"#FFFFFF"``.
+        :param visibility: Can be one of: ``"hidden"``, ``"private"``, or ``"public"``
+            (default: ``"private"``).
+        :param weighting_scheme: Can be one of: ``"classic"`` or ``"fresh"`` (default:
+            ``"classic"``).
 
-        :returns: The new Multireddit object.
+        :returns: The new :class:`.Multireddit` object.
 
         """
         model = {
@@ -351,19 +370,19 @@ class SubredditHelper(AsyncPRAWBase):
     async def __call__(
         self, display_name: str, fetch: bool = False
     ) -> "asyncpraw.models.Subreddit":
-        """Return an instance of :class:`~.Subreddit`.
+        """Return an instance of :class:`.Subreddit`.
+
+        :param display_name: The name of the subreddit.
+        :param fetch: Determines if Async PRAW will fetch the object (default:
+            ``False``).
 
         If you need the object fetched right away (e.g., to access an attribute) you can
         do:
 
         .. code-block:: python
 
-            multireddit = await reddit.subreddit("redditor", fetch=True)
-            async for comment in multireddit.comments(limit=25):
-                print(comment.author)
-
-        :param display_name: The name of the subreddit.
-        :param fetch: Determines if Async PRAW will fetch the object (default: False).
+            subreddit = await reddit.subreddit("test", fetch=True)
+            print(subreddit.subscribers)
 
         """
         lower_name = display_name.lower()
@@ -377,29 +396,32 @@ class SubredditHelper(AsyncPRAWBase):
             await subreddit._fetch()
         return subreddit
 
+    @_deprecate_args("name", "title", "link_type", "subreddit_type", "wikimode")
     async def create(
         self,
         name: str,
-        title: Optional[str] = None,
+        *,
         link_type: str = "any",
         subreddit_type: str = "public",
+        title: Optional[str] = None,
         wikimode: str = "disabled",
         **other_settings: Optional[str],
     ) -> "asyncpraw.models.Subreddit":
-        """Create a new subreddit.
+        """Create a new :class:`.Subreddit`.
 
         :param name: The name for the new subreddit.
+        :param link_type: The types of submissions users can make. One of ``"any"``,
+            ``"link"``, or ``"self"`` (default: ``"any"``).
+        :param subreddit_type: One of ``"archived"``, ``"employees_only"``,
+            ``"gold_only"``, ``"gold_restricted"``, ``"private"``, ``"public"``, or
+            ``"restricted"`` (default: ``"public"``).
         :param title: The title of the subreddit. When ``None`` or ``""`` use the value
             of ``name``.
-        :param link_type: The types of submissions users can make. One of ``any``,
-            ``link``, ``self`` (default: any).
-        :param subreddit_type: One of ``archived``, ``employees_only``, ``gold_only``,
-            ``gold_restricted``, ``private``, ``public``, ``restricted`` (default:
-            public).
-        :param wikimode: One of ``anyone``, ``disabled``, ``modonly``.
+        :param wikimode: One of ``"anyone"``, ``"disabled"``, or ``"modonly"`` (default:
+            ``"disabled"``).
 
-        Any keyword parameters not provided, or set explicitly to None, will take on a
-        default value assigned by the Reddit server.
+        Any keyword parameters not provided, or set explicitly to ``None``, will take on
+        a default value assigned by the Reddit server.
 
         .. seealso::
 
@@ -409,8 +431,8 @@ class SubredditHelper(AsyncPRAWBase):
         """
         await Subreddit._create_or_update(
             _reddit=self._reddit,
-            name=name,
             link_type=link_type,
+            name=name,
             subreddit_type=subreddit_type,
             title=title or name,
             wikimode=wikimode,
