@@ -20,7 +20,7 @@ class RisingListingMixin(AsyncPRAWBase):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        For example, to get random rising submissions for subreddit ``r/test``:
+        For example, to get random rising submissions for r/test:
 
         .. code-block:: python
 
@@ -41,7 +41,7 @@ class RisingListingMixin(AsyncPRAWBase):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        For example, to get rising submissions for subreddit ``r/test``:
+        For example, to get rising submissions for r/test:
 
         .. code-block:: python
 
