@@ -3,6 +3,7 @@ from typing import TYPE_CHECKING, Any, Dict, Generator, List, Optional, Union
 
 from ...const import API_PATH
 from ...exceptions import ClientException
+from ...util import _deprecate_args
 from ...util.cache import cachedproperty
 from ..base import AsyncPRAWBase
 from ..util import deprecate_lazy
@@ -22,7 +23,7 @@ class CollectionModeration(AsyncPRAWBase):
 
     .. code-block:: python
 
-        subreddit = await reddit.subreddit("SUBREDDIT")
+        subreddit = await reddit.subreddit("test")
         collection = await subreddit.collections("some_uuid")
         collection.mod
 
@@ -31,7 +32,7 @@ class CollectionModeration(AsyncPRAWBase):
     def _post_fullname(self, post):
         """Get a post's fullname.
 
-        :param post: A fullname, a Submission, a permalink, or an ID.
+        :param post: A fullname, a :class:`.Submission`, a permalink, or an ID.
 
         :returns: The fullname of the post.
 
@@ -48,9 +49,9 @@ class CollectionModeration(AsyncPRAWBase):
             return Submission(self._reddit, id=post).fullname
 
     def __init__(self, reddit: "asyncpraw.Reddit", collection_id: str):
-        """Initialize an instance of CollectionModeration.
+        """Initialize a :class:`.CollectionModeration` instance.
 
-        :param collection_id: The ID of a collection.
+        :param collection_id: The ID of a :class:`.Collection`.
 
         """
         super().__init__(reddit, _data=None)
@@ -66,7 +67,7 @@ class CollectionModeration(AsyncPRAWBase):
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             await collection.mod.add_post("bgibu9")
 
@@ -89,7 +90,7 @@ class CollectionModeration(AsyncPRAWBase):
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             await collection.mod.delete()
 
@@ -99,8 +100,7 @@ class CollectionModeration(AsyncPRAWBase):
 
         """
         await self._reddit.post(
-            API_PATH["collection_delete"],
-            data={"collection_id": self.collection_id},
+            API_PATH["collection_delete"], data={"collection_id": self.collection_id}
         )
 
     async def remove_post(self, submission: "asyncpraw.models.Submission"):
@@ -113,7 +113,7 @@ class CollectionModeration(AsyncPRAWBase):
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             await collection.mod.remove_post("bgibu9")
 
@@ -130,16 +130,16 @@ class CollectionModeration(AsyncPRAWBase):
         )
 
     async def reorder(self, links: List[Union[str, "asyncpraw.models.Submission"]]):
-        """Reorder posts in the collection.
+        r"""Reorder posts in the collection.
 
-        :param links: A ``list`` of submissions, as :class:`.Submission`, permalink as a
-            ``str``, fullname as a ``str``, or ID as a ``str``.
+        :param links: A list of :class:`.Submission`\ s or a ``str`` that is either a
+            fullname or an ID.
 
         Example usage:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             current_order = collection.link_ids
             new_order = reversed(current_order)
@@ -161,7 +161,7 @@ class CollectionModeration(AsyncPRAWBase):
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             await collection.mod.update_description("Please enjoy these links")
 
@@ -175,6 +175,32 @@ class CollectionModeration(AsyncPRAWBase):
             data={"collection_id": self.collection_id, "description": description},
         )
 
+    async def update_display_layout(self, display_layout: str):
+        """Update the collection's display layout.
+
+        :param display_layout: Either ``"TIMELINE"`` for events or discussions or
+            ``"GALLERY"`` for images or memes. Passing ``None`` will clear the set
+            layout and ``collection.display_layout`` will be ``None``, however, the
+            collection will appear on Reddit as if ``display_layout`` is set to
+            ``"TIMELINE"``.
+
+        Example usage:
+
+        .. code-block:: python
+
+            subreddit = await reddit.subreddit("test")
+            collection = await subreddit.collections("some_uuid")
+            await collection.mod.update_display_layout("GALLERY")
+
+        """
+        await self._reddit.post(
+            API_PATH["collection_layout"],
+            data={
+                "collection_id": self.collection_id,
+                "display_layout": display_layout,
+            },
+        )
+
     async def update_title(self, title: str):
         """Update the collection's title.
 
@@ -184,7 +210,7 @@ class CollectionModeration(AsyncPRAWBase):
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             await collection.mod.update_title("Titley McTitleface")
 
@@ -200,31 +226,25 @@ class CollectionModeration(AsyncPRAWBase):
 
 
 class Collection(RedditBase):
-    """Class to represent a Collection.
+    """Class to represent a :class:`.Collection`.
 
     Obtain an instance via:
 
     .. code-block:: python
 
-        subreddit = await reddit.subreddit("SUBREDDIT")
+        subreddit = await reddit.subreddit("test")
         collection = await subreddit.collections("some_uuid")
 
     or
 
     .. code-block:: python
 
-        subreddit = await reddit.subreddit("SUBREDDIT")
+        subreddit = await reddit.subreddit("test")
         collection = await subreddit.collections(
-            permalink="https://reddit.com/r/SUBREDDIT/collection/some_uuid"
+            permalink="https://reddit.com/r/test/collection/some_uuid"
         )
 
-    **Typical Attributes**
-
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor that they will be the only attributes
-    present.
+    .. include:: ../../typical_attributes.rst
 
     =================== =============================================================
     Attribute           Description
@@ -233,9 +253,10 @@ class Collection(RedditBase):
     ``collection_id``   The UUID of the collection.
     ``created_at_utc``  Time the collection was created, represented in `Unix Time`_.
     ``description``     The collection description.
+    ``display_layout``  The collection display layout.
     ``last_update_utc`` Time the collection was last updated, represented in `Unix
                         Time`_.
-    ``link_ids``        A ``list`` of :class:`.Submission` fullnames.
+    ``link_ids``        A list of :class:`.Submission` fullnames.
     ``permalink``       The collection's permalink (to view on the web).
     ``sorted_links``    An iterable listing of the posts in this collection.
     ``title``           The title of the collection.
@@ -261,7 +282,7 @@ class Collection(RedditBase):
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             await collection.mod.update_title("My new title!")
 
@@ -275,12 +296,12 @@ class Collection(RedditBase):
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             print(await collection.subreddit())
 
         """
-        async for subreddit in self._reddit.info([self.subreddit_id]):
+        async for subreddit in self._reddit.info(fullnames=[self.subreddit_id]):
             return subreddit
 
     def __init__(
@@ -290,12 +311,12 @@ class Collection(RedditBase):
         collection_id: Optional[str] = None,
         permalink: Optional[str] = None,
     ):
-        """Initialize this collection.
+        """Initialize a :class:`.Collection` instance.
 
         :param reddit: An instance of :class:`.Reddit`.
-        :param _data: Any data associated with the Collection (optional).
-        :param collection_id: The ID of the Collection (optional).
-        :param permalink: The permalink of the Collection (optional).
+        :param _data: Any data associated with the :class:`.Collection`.
+        :param collection_id: The ID of the :class:`.Collection`.
+        :param permalink: The permalink of the :class:`.Collection`.
 
         """
         if (_data, collection_id, permalink).count(None) != 2:
@@ -317,13 +338,13 @@ class Collection(RedditBase):
         }
 
     def __iter__(self) -> Generator[Any, None, None]:
-        """Provide a way to iterate over the posts in this Collection.
+        """Provide a way to iterate over the posts in this :class:`.Collection`.
 
         Example usage:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             for submission in collection:
                 print(submission.title, submission.permalink)
@@ -333,13 +354,13 @@ class Collection(RedditBase):
             yield item
 
     def __len__(self) -> int:
-        """Get the number of posts in this Collection.
+        """Get the number of posts in this :class:`.Collection`.
 
         Example usage:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             print(len(collection))
 
@@ -360,7 +381,7 @@ class Collection(RedditBase):
     async def _fetch_data(self):
         name, fields, params = self._fetch_info()
         path = API_PATH[name].format(**fields)
-        return await self._reddit.request("GET", path, params)
+        return await self._reddit.request(method="GET", params=params, path=path)
 
     async def _fetch(self):
         data = await self._fetch_data()
@@ -380,19 +401,19 @@ class Collection(RedditBase):
         self._fetched = True
 
     async def follow(self):
-        """Follow this Collection.
+        """Follow this :class:`.Collection`.
 
         Example usage:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             await collection.follow()
 
         .. seealso::
 
-            :meth:`~.unfollow`
+            :meth:`.unfollow`
 
         """
         await self._reddit.post(
@@ -401,19 +422,19 @@ class Collection(RedditBase):
         )
 
     async def unfollow(self):
-        """Unfollow this Collection.
+        """Unfollow this :class:`.Collection`.
 
         Example usage:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             collection = await subreddit.collections("some_uuid")
             await collection.unfollow()
 
         .. seealso::
 
-            :meth:`~.follow`
+            :meth:`.follow`
 
         """
         await self._reddit.post(
@@ -423,13 +444,13 @@ class Collection(RedditBase):
 
 
 class SubredditCollectionsModeration(AsyncPRAWBase):
-    """Class to represent moderator actions on a Subreddit's Collections.
+    r"""Class to represent moderator actions on a :class:`.Subreddit`'s :class:`.Collection`\ s.
 
     Obtain an instance via:
 
     .. code-block:: python
 
-        subreddit = await reddit.subreddit("SUBREDDIT")
+        subreddit = await reddit.subreddit("test")
         subreddit.collections.mod
 
     """
@@ -440,18 +461,25 @@ class SubredditCollectionsModeration(AsyncPRAWBase):
         subreddit: "asyncpraw.models.Subreddit",
         _data: Optional[Dict[str, Any]] = None,
     ):
-        """Initialize the SubredditCollectionsModeration instance."""
+        """Initialize a :class:`.SubredditCollectionsModeration` instance."""
         super().__init__(reddit, _data)
         self.subreddit = subreddit
 
-    async def create(self, title: str, description: str):
+    @_deprecate_args("title", "description", "display_layout")
+    async def create(
+        self, *, description: str, display_layout: Optional[str] = None, title: str
+    ):
         """Create a new :class:`.Collection`.
 
         The authenticated account must have appropriate moderator permissions in the
         subreddit this collection belongs to.
 
-        :param title: The title of the collection, up to 300 characters.
         :param description: The description, up to 500 characters.
+        :param display_layout: Either ``"TIMELINE"`` for events or discussions or
+            ``"GALLERY"`` for images or memes. Passing ``""`` or ``None`` will make the
+            collection appear on Reddit as if this is set to ``"TIMELINE"`` (default:
+            ``None``).
+        :param title: The title of the collection, up to 300 characters.
 
         :returns: The newly created :class:`.Collection`.
 
@@ -459,35 +487,48 @@ class SubredditCollectionsModeration(AsyncPRAWBase):
 
         .. code-block:: python
 
-            sub = await reddit.subreddit("SUBREDDIT")
-            new_collection = await sub.collections.mod.create("Title", "desc")
+            sub = await reddit.subreddit("test")
+            new_collection = await sub.collections.mod.create(title="Title", description="desc")
+            await new_collection.mod.add_post("bgibu9")
+
+        To specify the display layout as ``"GALLERY"`` when creating the collection:
+
+        .. code-block:: python
+
+            my_sub = await reddit.subreddit("test")
+            new_collection = await my_sub.collections.mod.create(
+                title="Title", description="desc", display_layout="GALLERY"
+            )
             await new_collection.mod.add_post("bgibu9")
 
         .. seealso::
 
-            :meth:`~CollectionModeration.delete`
+            :meth:`~.CollectionModeration.delete`
 
         """
         if not self.subreddit._fetched:
             await self.subreddit._fetch()
+        data = {
+            "sr_fullname": self.subreddit.fullname,
+            "title": title,
+            "description": description,
+        }
+        if display_layout:
+            data["display_layout"] = display_layout
         return await self._reddit.post(
             API_PATH["collection_create"],
-            data={
-                "sr_fullname": self.subreddit.fullname,
-                "title": title,
-                "description": description,
-            },
+            data=data,
         )
 
 
 class SubredditCollections(AsyncPRAWBase):
-    r"""Class to represent a Subreddit's :class:`.Collection`\ s.
+    r"""Class to represent a :class:`.Subreddit`'s :class:`.Collection`\ s.
 
     Obtain an instance via:
 
     .. code-block:: python
 
-        subreddit = await reddit.subreddit("SUBREDDIT")
+        subreddit = await reddit.subreddit("test")
         subreddit.collections
 
     """
@@ -500,8 +541,8 @@ class SubredditCollections(AsyncPRAWBase):
 
         .. code-block:: python
 
-            my_sub = await reddit.subreddit("SUBREDDIT", fetch=True)
-            new_collection = await my_sub.collections.mod.create("Title", "desc")
+            my_sub = await reddit.subreddit("test", fetch=True)
+            new_collection = await my_sub.collections.mod.create(title="Title", description="desc")
 
         """
         return SubredditCollectionsModeration(self._reddit, self.subreddit)
@@ -516,26 +557,27 @@ class SubredditCollections(AsyncPRAWBase):
     ):
         """Return the :class:`.Collection` with the specified ID.
 
-        :param collection_id: The ID of a Collection (default: None).
-        :param permalink: The permalink of a Collection (default: None).
-        :param fetch: Determines if Async PRAW will fetch the object (default: True).
+        :param collection_id: The ID of a :class:`.Collection` (default: ``None``).
+        :param permalink: The permalink of a collection (default: ``None``).
+        :param fetch: Determines if Async PRAW will fetch the object (default:
+            ``True``).
 
-        :returns: The specified Collection.
+        :returns: The specified :class:`.Collection`.
 
-        Exactly one of ``collection_id`` and ``permalink`` is required.
+        Exactly one of ``collection_id`` or ``permalink`` is required.
 
         Example usage:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
 
             uuid = "847e4548-a3b5-4ad7-afb4-edbfc2ed0a6b"
             collection = await subreddit.collections(uuid)
             print(collection.title)
             print(collection.description)
 
-            permalink = "https://www.reddit.com/r/SUBREDDIT/collection/" + uuid
+            permalink = "https://www.reddit.com/r/test/collection/" + uuid
             collection = await subreddit.collections(permalink=permalink)
             print(collection.title)
             print(collection.description)
@@ -545,7 +587,7 @@ class SubredditCollections(AsyncPRAWBase):
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT", fetch=True)
+            subreddit = await reddit.subreddit("test", fetch=True)
             collection = await subreddit.collections(uuid, fetch=False)
             await collection.mod.add("submission_id")
 
@@ -567,18 +609,18 @@ class SubredditCollections(AsyncPRAWBase):
         subreddit: "asyncpraw.models.Subreddit",
         _data: Optional[Dict[str, Any]] = None,
     ):
-        """Initialize an instance of SubredditCollections."""
+        """Initialize a :class:`.SubredditCollections` instance."""
         super().__init__(reddit, _data)
         self.subreddit = subreddit
 
     async def __aiter__(self):
-        r"""Iterate over the Subreddit's :class:`.Collection`\ s.
+        r"""Iterate over the :class:`.Subreddit`'s :class:`.Collection`\ s.
 
         Example usage:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
+            subreddit = await reddit.subreddit("test")
             async for collection in subreddit.collections:
                 print(collection.permalink)
 
