@@ -2,6 +2,7 @@
 from typing import TYPE_CHECKING, Any, AsyncIterator, Dict, List, Optional, Union
 
 from ...const import API_PATH
+from ...util import _deprecate_args
 from ...util.cache import cachedproperty
 from ..list.redditor import RedditorList
 from ..listing.generator import ListingGenerator
@@ -48,15 +49,14 @@ class LiveContributorRelationship:
         return generator()
 
     def __init__(self, thread: "asyncpraw.models.LiveThread"):
-        """Create a :class:`.LiveContributorRelationship` instance.
+        """Initialize a :class:`.LiveContributorRelationship` instance.
 
         :param thread: An instance of :class:`.LiveThread`.
 
         .. note::
 
-            This class should not be initialized directly. Instead obtain an instance
-            via: ``thread.contributor`` where ``thread`` is a :class:`.LiveThread`
-            instance.
+            This class should not be initialized directly. Instead, obtain an instance
+            via: :meth:`.LiveThread.contributor`.
 
         """
         self.thread = thread
@@ -75,15 +75,16 @@ class LiveContributorRelationship:
         url = API_PATH["live_accept_invite"].format(id=self.thread.id)
         await self.thread._reddit.post(url)
 
+    @_deprecate_args("redditor", "permissions")
     async def invite(
         self,
         redditor: Union[str, "asyncpraw.models.Redditor"],
+        *,
         permissions: Optional[List[str]] = None,
     ):
         """Invite a redditor to be a contributor of the live thread.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
-            instance.
+        :param redditor: A redditor name or :class:`.Redditor` instance.
         :param permissions: When provided (not ``None``), permissions should be a list
             of strings specifying which subset of permissions to grant. An empty list
             ``[]`` indicates no permissions, and when not provided (``None``), indicates
@@ -99,7 +100,7 @@ class LiveContributorRelationship:
             redditor = await reddit.redditor("spez", fetch=False)
 
             # "manage" and "settings" permissions
-            await thread.contributor.invite(redditor, ["manage", "settings"])
+            await thread.contributor.invite(redditor, permissions=["manage", "settings"])
 
         .. seealso::
 
@@ -132,8 +133,8 @@ class LiveContributorRelationship:
     async def remove(self, redditor: Union[str, "asyncpraw.models.Redditor"]):
         """Remove the redditor from the live thread contributors.
 
-        :param redditor: A redditor fullname (e.g., ``"t2_1w72"``) or
-            :class:`~.Redditor` instance.
+        :param redditor: A redditor fullname (e.g., ``"t2_1w72"``) or :class:`.Redditor`
+            instance.
 
         Usage:
 
@@ -156,8 +157,8 @@ class LiveContributorRelationship:
     async def remove_invite(self, redditor: Union[str, "asyncpraw.models.Redditor"]):
         """Remove the invite for redditor.
 
-        :param redditor: A redditor fullname (e.g., ``"t2_1w72"``) or
-            :class:`~.Redditor` instance.
+        :param redditor: A redditor fullname (e.g., ``"t2_1w72"``) or :class:`.Redditor`
+            instance.
 
         Usage:
 
@@ -182,15 +183,16 @@ class LiveContributorRelationship:
         url = API_PATH["live_remove_invite"].format(id=self.thread.id)
         await self.thread._reddit.post(url, data=data)
 
+    @_deprecate_args("redditor", "permissions")
     async def update(
         self,
         redditor: Union[str, "asyncpraw.models.Redditor"],
+        *,
         permissions: Optional[List[str]] = None,
     ):
         """Update the contributor permissions for ``redditor``.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
-            instance.
+        :param redditor: A redditor name or :class:`.Redditor` instance.
         :param permissions: When provided (not ``None``), permissions should be a list
             of strings specifying which subset of permissions to grant (other
             permissions are removed). An empty list ``[]`` indicates no permissions, and
@@ -208,13 +210,13 @@ class LiveContributorRelationship:
 
         .. code-block:: python
 
-            await thread.contributor.update("spez", ["access", "edit"])
+            await thread.contributor.update("spez", permissions=["access", "edit"])
 
         To remove all permissions from the contributor, try:
 
         .. code-block:: python
 
-            await subreddit.moderator.update("spez", [])
+            await subreddit.moderator.update("spez", permissions=[])
 
         """
         url = API_PATH["live_update_perms"].format(id=self.thread.id)
@@ -225,15 +227,16 @@ class LiveContributorRelationship:
         }
         await self.thread._reddit.post(url, data=data)
 
+    @_deprecate_args("redditor", "permissions")
     async def update_invite(
         self,
         redditor: Union[str, "asyncpraw.models.Redditor"],
+        *,
         permissions: Optional[List[str]] = None,
     ):
         """Update the contributor invite permissions for ``redditor``.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
-            instance.
+        :param redditor: A redditor name or :class:`.Redditor` instance.
         :param permissions: When provided (not ``None``), permissions should be a list
             of strings specifying which subset of permissions to grant (other
             permissions are removed). An empty list ``[]`` indicates no permissions, and
@@ -246,18 +249,18 @@ class LiveContributorRelationship:
             thread = await reddit.live("ukaeu1ik4sw5")
             await thread.contributor.update_invite("spez")
 
-        To set "access" and "edit" permissions (and to remove other permissions) to the
-        invitation, try:
+        To set ``"access"`` and ``"edit"`` permissions (and to remove other permissions)
+        to the invitation, try:
 
         .. code-block:: python
 
-            await thread.contributor.update_invite("spez", ["access", "edit"])
+            await thread.contributor.update_invite("spez", permissions=["access", "edit"])
 
         To remove all permissions from the invitation, try:
 
         .. code-block:: python
 
-            await thread.contributor.update_invite("spez", [])
+            await thread.contributor.update_invite("spez", permissions=[])
 
         """
         url = API_PATH["live_update_perms"].format(id=self.thread.id)
@@ -270,14 +273,9 @@ class LiveContributorRelationship:
 
 
 class LiveThread(RedditBase):
-    """An individual LiveThread object.
+    """An individual :class:`.LiveThread` object.
 
-    **Typical Attributes**
-
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor is this list necessarily complete.
+    .. include:: ../../typical_attributes.rst
 
     ==================== =========================================================
     Attribute            Description
@@ -316,13 +314,13 @@ class LiveThread(RedditBase):
 
         You can call the instance to get a list of contributors which is represented as
         :class:`.RedditorList` instance consists of :class:`.Redditor` instances. Those
-        Redditor instances have ``permissions`` attributes as contributors:
+        :class:`.Redditor` instances have ``permissions`` attributes as contributors:
 
         .. code-block:: python
 
             thread = await reddit.live("ukaeu1ik4sw5")
             async for contributor in thread.contributor():
-                # prints `(Redditor(name="Acidtwist"), [u"all"])`
+                # prints `Redditor(name="Acidtwist") [u"all"]`
                 print(contributor, contributor.permissions)
 
         """
@@ -373,7 +371,8 @@ class LiveThread(RedditBase):
 
         :param update_id: A live update ID, e.g.,
             ``"7827987a-c998-11e4-a0b9-22000b6a88d2"``.
-        :param fetch: Determines if Async PRAW will fetch the object (default: True).
+        :param fetch: Determines if Async PRAW will fetch the object (default:
+            ``True``).
 
         Usage:
 
@@ -410,7 +409,7 @@ class LiveThread(RedditBase):
         id: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,  # pylint: disable=redefined-builtin
     ):
-        """Initialize a lazy :class:`.LiveThread` instance.
+        """Initialize a :class:`.LiveThread` instance.
 
         :param reddit: An instance of :class:`.Reddit`.
         :param id: A live thread ID, e.g., ``"ukaeu1ik4sw5"``
@@ -428,7 +427,7 @@ class LiveThread(RedditBase):
     async def _fetch_data(self):
         name, fields, params = self._fetch_info()
         path = API_PATH[name].format(**fields)
-        return await self._reddit.request("GET", path, params)
+        return await self._reddit.request(method="GET", params=params, path=path)
 
     async def _fetch(self):
         data = await self._fetch_data()
@@ -467,7 +466,8 @@ class LiveThread(RedditBase):
         """Report the thread violating the Reddit rules.
 
         :param type: One of ``"spam"``, ``"vote-manipulation"``,
-            ``"personal-information"``, ``"sexualizing-minors"``, ``"site-breaking"``.
+            ``"personal-information"``, ``"sexualizing-minors"``, or
+            ``"site-breaking"``.
 
         Usage:
 
@@ -511,10 +511,10 @@ class LiveThread(RedditBase):
 
 
 class LiveThreadContribution:
-    """Provides a set of contribution functions to a LiveThread."""
+    """Provides a set of contribution functions to a :class:`.LiveThread`."""
 
     def __init__(self, thread: "asyncpraw.models.LiveThread"):
-        """Create an instance of :class:`.LiveThreadContribution`.
+        """Initialize a :class:`.LiveThreadContribution` instance.
 
         :param thread: An instance of :class:`.LiveThread`.
 
@@ -559,22 +559,24 @@ class LiveThreadContribution:
         url = API_PATH["live_close"].format(id=self.thread.id)
         await self.thread._reddit.post(url)
 
+    @_deprecate_args("title", "description", "nsfw", "resources")
     async def update(
         self,
-        title: Optional[str] = None,
+        *,
         description: Optional[str] = None,
         nsfw: Optional[bool] = None,
         resources: Optional[str] = None,
+        title: Optional[str] = None,
         **other_settings: Optional[str],
     ):
         """Update settings of the live thread.
 
-        :param title: (Optional) The title of the live thread (default: None).
-        :param description: (Optional) The live thread's description (default: None).
-        :param nsfw: (Optional) Indicate whether this thread is not safe for work
-            (default: None).
-        :param resources: (Optional) Markdown formatted information that is useful for
-            the live thread (default: None).
+        :param description: The live thread's description (default: ``None``).
+        :param nsfw: Indicate whether this thread is not safe for work (default:
+            ``None``).
+        :param resources: Markdown formatted information that is useful for the live
+            thread (default: ``None``).
+        :param title: The title of the live thread (default: ``None``).
 
         Does nothing if no arguments are provided.
 
@@ -636,7 +638,7 @@ class LiveThreadStream:
     """
 
     def __init__(self, live_thread: "asyncpraw.models.LiveThread"):
-        """Create a LiveThreadStream instance.
+        """Initialize a :class:`.LiveThreadStream` instance.
 
         :param live_thread: The live thread associated with the stream.
 
@@ -684,12 +686,7 @@ class LiveThreadStream:
 class LiveUpdate(FullnameMixin, RedditBase):
     """An individual :class:`.LiveUpdate` object.
 
-    **Typical Attributes**
-
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor is this list necessarily complete.
+    .. include:: ../../typical_attributes.rst
 
     =============== ===================================================================
     Attribute       Description
@@ -736,7 +733,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
         update_id: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
     ):
-        """Initialize a lazy :class:`.LiveUpdate` instance.
+        """Initialize a :class:`.LiveUpdate` instance.
 
         Either ``thread_id`` and ``update_id``, or ``_data`` must be provided.
 
@@ -785,10 +782,10 @@ class LiveUpdate(FullnameMixin, RedditBase):
 
 
 class LiveUpdateContribution:
-    """Provides a set of contribution functions to LiveUpdate."""
+    """Provides a set of contribution functions to :class:`.LiveUpdate`."""
 
     def __init__(self, update: "asyncpraw.models.LiveUpdate"):
-        """Create an instance of :class:`.LiveUpdateContribution`.
+        """Initialize a :class:`.LiveUpdateContribution` instance.
 
         :param update: An instance of :class:`.LiveUpdate`.
 
