@@ -3,36 +3,33 @@ from ....const import API_PATH
 
 
 class ReplyableMixin:
-    """Interface for RedditBase classes that can be replied to."""
+    """Interface for :class:`.RedditBase` classes that can be replied to."""
 
     async def reply(self, body: str):
         """Reply to the object.
 
         :param body: The Markdown formatted content for a comment.
 
-        :returns: A :class:`~.Comment` object for the newly created comment or ``None``
+        :returns: A :class:`.Comment` object for the newly created comment or ``None``
             if Reddit doesn't provide one.
 
+        :raises: ``asyncprawcore.exceptions.Forbidden`` when attempting to reply to some
+            items, such as locked submissions/comments or non-replyable messages.
+
         A ``None`` value can be returned if the target is a comment or submission in a
         quarantined subreddit and the authenticated user has not opt-ed in to viewing
         the content. When this happens the comment will be successfully created on
         Reddit and can be retried by drawing the comment from the user's comment
         history.
 
-        .. note::
-
-            Some items, such as locked submissions/comments or non-replyable messages
-            will throw ``asyncprawcore.exceptions.Forbidden`` when attempting to reply
-            to them.
-
         Example usage:
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", fetch=False)
+            submission = await reddit.submission("5or86n", fetch=False)
             await submission.reply("reply")
 
-            comment = await reddit.comment(id="dxolpyc", fetch=False)
+            comment = await reddit.comment("dxolpyc", fetch=False)
             await comment.reply("reply")
 
         """
