@@ -3,7 +3,7 @@ from ....const import API_PATH
 
 
 class VotableMixin:
-    """Interface for RedditBase classes that can be voted on."""
+    """Interface for :class:`.RedditBase` classes that can be voted on."""
 
     async def _vote(self, direction):
         await self._reddit.post(
@@ -18,17 +18,17 @@ class VotableMixin:
             Votes must be cast by humans. That is, API clients proxying a human's action
             one-for-one are OK, but bots deciding how to vote on content or amplifying a
             human's vote are not. See the reddit rules for more details on what
-            constitutes vote cheating. [`Ref
+            constitutes vote manipulation. [`Ref
             <https://www.reddit.com/dev/api#POST_api_vote>`_]
 
         Example usage:
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", fetch=False)
+            submission = await reddit.submission("5or86n", fetch=False)
             await submission.clear_vote()
 
-            comment = await reddit.comment(id="dxolpyc", fetch=False)
+            comment = await reddit.comment("dxolpyc", fetch=False)
             await comment.clear_vote()
 
         """
@@ -42,22 +42,22 @@ class VotableMixin:
             Votes must be cast by humans. That is, API clients proxying a human's action
             one-for-one are OK, but bots deciding how to vote on content or amplifying a
             human's vote are not. See the reddit rules for more details on what
-            constitutes vote cheating. [`Ref
+            constitutes vote manipulation. [`Ref
             <https://www.reddit.com/dev/api#POST_api_vote>`_]
 
         Example usage:
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", fetch=False)
+            submission = await reddit.submission("5or86n", fetch=False)
             await submission.downvote()
 
-            comment = await reddit.comment(id="dxolpyc", fetch=False)
+            comment = await reddit.comment("dxolpyc", fetch=False)
             await comment.downvote()
 
         .. seealso::
 
-            :meth:`~.upvote`
+            :meth:`.upvote`
 
         """
         await self._vote(direction=-1)
@@ -70,22 +70,22 @@ class VotableMixin:
             Votes must be cast by humans. That is, API clients proxying a human's action
             one-for-one are OK, but bots deciding how to vote on content or amplifying a
             human's vote are not. See the reddit rules for more details on what
-            constitutes vote cheating. [`Ref
+            constitutes vote manipulation. [`Ref
             <https://www.reddit.com/dev/api#POST_api_vote>`_]
 
         Example usage:
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", fetch=False)
+            submission = await reddit.submission("5or86n", fetch=False)
             await submission.upvote()
 
-            comment = await reddit.comment(id="dxolpyc", fetch=False)
+            comment = await reddit.comment("dxolpyc", fetch=False)
             await comment.upvote()
 
         .. seealso::
 
-            :meth:`~.downvote`
+            :meth:`.downvote`
 
         """
         await self._vote(direction=1)
