@@ -4,6 +4,7 @@ from warnings import warn
 
 from ...const import API_PATH
 from ...exceptions import ClientException
+from ...util import _deprecate_args
 from ..util import deprecate_lazy
 from .base import RedditBase
 
@@ -14,17 +15,12 @@ if TYPE_CHECKING:  # pragma: no cover
 class RemovalReason(RedditBase):
     """An individual Removal Reason object.
 
-    **Typical Attributes**
-
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor is this list necessarily complete.
+    .. include:: ../../typical_attributes.rst
 
     =========== ==================================
     Attribute   Description
     =========== ==================================
-    ``id``      The id of the removal reason.
+    ``id``      The ID of the removal reason.
     ``message`` The message of the removal reason.
     ``title``   The title of the removal reason.
     =========== ==================================
@@ -34,12 +30,12 @@ class RemovalReason(RedditBase):
     STR_FIELD = "id"
 
     @staticmethod
-    def _warn_reason_id(reason_id_value: Optional[str], id_value: Optional[str]):
-        """Reason id param is deprecated. Warns if it's used.
+    def _warn_reason_id(*, id_value: Optional[str], reason_id_value: Optional[str]):
+        """Reason ID param is deprecated. Warns if it's used.
 
-        :param reason_id_value: The value passed as parameter ``reason_id``.
         :param id_value: Returns the actual value of parameter ``id`` is parameter
             ``reason_id`` is not used.
+        :param reason_id_value: The value passed as parameter ``reason_id``.
 
         """
         if reason_id_value is not None:
@@ -72,16 +68,16 @@ class RemovalReason(RedditBase):
         reason_id: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
     ):
-        """Construct an instance of the Removal Reason object.
+        """Initialize a :class:`.RemovalReason` instance.
 
         :param reddit: An instance of :class:`.Reddit`.
         :param subreddit: An instance of :class:`.Subreddit`.
-        :param id: The id of the removal reason.
-        :param reason_id: (Deprecated) The original name of the ``id`` parameter. Used
-            for backwards compatibility. This parameter should not be used.
+        :param id: The ID of the removal reason.
+        :param reason_id: The original name of the ``id`` parameter. Used for backwards
+            compatibility. This parameter should not be used.
 
         """
-        id = self._warn_reason_id(reason_id, id)
+        id = self._warn_reason_id(id_value=id, reason_id_value=reason_id)
         if (id, _data).count(None) != 1:
             raise ValueError("Either id or _data needs to be given.")
 
@@ -103,11 +99,11 @@ class RemovalReason(RedditBase):
     async def delete(self):
         """Delete a removal reason from this subreddit.
 
-        To delete ``"141vv5c16py7d"`` from the subreddit ``"NAME"`` try:
+        To delete ``"141vv5c16py7d"`` from r/test try:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("NAME")
+            subreddit = await reddit.subreddit("test")
             reason = await subreddit.mod.removal_reasons.get_reason("141vv5c16py7d")
             await reason.delete()
 
@@ -115,7 +111,10 @@ class RemovalReason(RedditBase):
         url = API_PATH["removal_reason"].format(subreddit=self.subreddit, id=self.id)
         await self._reddit.delete(url)
 
-    async def update(self, message: Optional[str] = None, title: Optional[str] = None):
+    @_deprecate_args("message", "title")
+    async def update(
+        self, *, message: Optional[str] = None, title: Optional[str] = None
+    ):
         """Update the removal reason from this subreddit.
 
         .. note::
@@ -125,13 +124,13 @@ class RemovalReason(RedditBase):
         :param message: The removal reason's new message.
         :param title: The removal reason's new title.
 
-        To update ``"141vv5c16py7d"`` from the subreddit ``"NAME"`` try:
+        To update ``"141vv5c16py7d"`` from r/test try:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("NAME")
+            subreddit = await reddit.subreddit("test")
             reason = await subreddit.mod.removal_reasons.get_reason("141vv5c16py7d")
-            await reason.update(message="New message", title="New title")
+            await reason.update(title="New title", message="New message")
 
         """
         url = API_PATH["removal_reason"].format(subreddit=self.subreddit, id=self.id)
@@ -143,7 +142,7 @@ class RemovalReason(RedditBase):
 
 
 class SubredditRemovalReasons:
-    """Provide a set of functions to a Subreddit's removal reasons."""
+    """Provide a set of functions to a :class:`.Subreddit`'s removal reasons."""
 
     @deprecate_lazy
     async def get_reason(
@@ -152,14 +151,15 @@ class SubredditRemovalReasons:
         """Return the Removal Reason with the ID/number/slice ``reason_id``.
 
         :param reason_id: The ID or index of the removal reason.
-        :param fetch: Determines if Async PRAW will fetch the object (default: True).
+        :param fetch: Determines if Async PRAW will fetch the object (default:
+            ``True``).
 
         This method is to be used to fetch a specific removal reason, like so:
 
         .. code-block:: python
 
             reason_id = "141vv5c16py7d"
-            subreddit = await reddit.subreddit("NAME")
+            subreddit = await reddit.subreddit("test")
             reason = await subreddit.mod.removal_reasons.get_reason(reason_id)
             print(reason)
 
@@ -174,18 +174,18 @@ class SubredditRemovalReasons:
         :raises: :py:class:`IndexError` if a removal reason of a specific number does
             not exist.
 
-        For example, to get the second removal reason of the subreddit ``"NAME"``:
+        For example, to get the second removal reason of r/test:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("NAME")
+            subreddit = await reddit.subreddit("test")
             await subreddit.mod.removal_reasons.get_reason(1)
 
         To get the last three removal reasons in a subreddit:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("NAME")
+            subreddit = await reddit.subreddit("test")
             reasons = await subreddit.mod.removal_reasons.get_reason(slice(-3, None))
             for reason in reasons:
                 print(reason)
@@ -196,7 +196,7 @@ class SubredditRemovalReasons:
         .. code-block:: python
 
             reason_id = "141vv5c16py7d"
-            subreddit = await reddit.subreddit("NAME")
+            subreddit = await reddit.subreddit("test")
             reason = await subreddit.mod.removal_reasons.get_reason(reason_id, fetch=False)
             await reason.delete()
 
@@ -211,7 +211,7 @@ class SubredditRemovalReasons:
         return reason
 
     def __init__(self, subreddit: "asyncpraw.models.Subreddit"):
-        """Create a SubredditRemovalReasons instance.
+        """Initialize a :class:`.SubredditRemovalReasons` instance.
 
         :param subreddit: The subreddit whose removal reasons to work with.
 
@@ -226,7 +226,7 @@ class SubredditRemovalReasons:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("NAME")
+            subreddit = await reddit.subreddit("test")
             async for removal_reason in subreddit.mod.removal_reasons:
                 print(removal_reason)
 
@@ -248,22 +248,23 @@ class SubredditRemovalReasons:
             for id, reason_data in response["data"].items()
         ]
 
-    async def add(self, message: str, title: str) -> RemovalReason:
+    @_deprecate_args("message", "title")
+    async def add(self, *, message: str, title: str) -> RemovalReason:
         """Add a removal reason to this subreddit.
 
         :param message: The message associated with the removal reason.
-        :param title: The title of the removal reason
+        :param title: The title of the removal reason.
 
-        :returns: The RemovalReason added.
+        :returns: The :class:`.RemovalReason` added.
 
-        The message will be prepended with `Hi u/username,` automatically.
+        The message will be prepended with ``Hi u/username,`` automatically.
 
-        To add ``"Test"`` to the subreddit ``"NAME"`` try:
+        To add ``"Test"`` to r/test try:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("NAME")
-            await subreddit.mod.removal_reasons.add(message="Foobar", title="Test")
+            subreddit = await reddit.subreddit("test")
+            await subreddit.mod.removal_reasons.add(title="Test", message="Foobar")
 
         """
         data = {"message": message, "title": title}
