@@ -10,6 +10,7 @@ from typing import (
 )
 
 from ...const import API_PATH
+from ...util import _deprecate_args
 from ...util.cache import cachedproperty
 from ..listing.generator import ListingGenerator
 from .base import RedditBase
@@ -20,7 +21,7 @@ if TYPE_CHECKING:  # pragma: no cover
 
 
 class WikiPageModeration:
-    """Provides a set of moderation functions for a WikiPage.
+    """Provides a set of moderation functions for a :class:`.WikiPage`.
 
     For example, to add ``spez`` as an editor on the wikipage ``praw_test`` try:
 
@@ -33,7 +34,7 @@ class WikiPageModeration:
     """
 
     def __init__(self, wikipage: "WikiPage"):
-        """Create a WikiPageModeration instance.
+        """Initialize a :class:`.WikiPageModeration` instance.
 
         :param wikipage: The wikipage to moderate.
 
@@ -41,12 +42,11 @@ class WikiPageModeration:
         self.wikipage = wikipage
 
     async def add(self, redditor: "asyncpraw.models.Redditor"):
-        """Add an editor to this WikiPage.
+        """Add an editor to this :class:`.WikiPage`.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
-            instance.
+        :param redditor: A redditor name or :class:`.Redditor` instance.
 
-        To add ``"spez"`` as an editor on the wikipage ``"praw_test"`` try:
+        To add u/spez as an editor on the wikipage ``"praw_test"`` try:
 
         .. code-block:: python
 
@@ -62,12 +62,11 @@ class WikiPageModeration:
         await self.wikipage._reddit.post(url, data=data)
 
     async def remove(self, redditor: "asyncpraw.models.Redditor"):
-        """Remove an editor from this WikiPage.
+        """Remove an editor from this :class:`.WikiPage`.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
-            instance.
+        :param redditor: A redditor name or :class:`.Redditor` instance.
 
-        To remove ``"spez"`` as an editor on the wikipage ``"praw_test"`` try:
+        To remove u/spez as an editor on the wikipage ``"praw_test"`` try:
 
         .. code-block:: python
 
@@ -85,13 +84,13 @@ class WikiPageModeration:
     async def revert(self):
         """Revert a wikipage back to a specific revision.
 
-        To revert the page ``"praw_test"`` in ``r/test`` to revision ``[ID]``, try
+        To revert the page ``"praw_test"`` in r/test to revision ``"1234abc"``, try
 
         .. code-block:: python
 
             subreddit = await reddit.subreddit("test")
             wikipage = await subreddit.wiki.get_page("praw_test")
-            revision = await wikipage.revision("[ID]")
+            revision = await wikipage.revision("1234abc")
             await revision.mod.revert()
 
         .. note::
@@ -99,7 +98,7 @@ class WikiPageModeration:
             When you attempt to revert the page ``config/stylesheet``, Reddit checks to
             see if the revision being reverted to passes the CSS filter. If the check
             fails, then the revision attempt will also fail, and a
-            ``prawcore.Forbidden`` exception will be raised. For example, you can't
+            ``asyncprawcore.Forbidden`` exception will be raised. For example, you can't
             revert to a revision that contains a link to ``url(%%PRAW%%)`` if there is
             no image named ``PRAW`` on the current stylesheet.
 
@@ -112,7 +111,7 @@ class WikiPageModeration:
                 try:
                     subreddit = await reddit.subreddit("test")
                     wikipage = await subreddit.wiki.get_page("config/stylesheet")
-                    revision = await wikipage.revision("[ID]")
+                    revision = await wikipage.revision("1234abc")
                     await revision.mod.revert()
                 except Forbidden as exception:
                     try:
@@ -136,27 +135,28 @@ class WikiPageModeration:
         )
 
     async def settings(self) -> Dict[str, Any]:
-        """Return the settings for this WikiPage."""
+        """Return the settings for this :class:`.WikiPage`."""
         url = API_PATH["wiki_page_settings"].format(
             subreddit=self.wikipage.subreddit, page=self.wikipage.name
         )
         response = await self.wikipage._reddit.get(url)
         return response["data"]
 
+    @_deprecate_args("listed", "permlevel")
     async def update(
-        self, listed: bool, permlevel: int, **other_settings: Any
+        self, *, listed: bool, permlevel: int, **other_settings: Any
     ) -> Dict[str, Any]:
-        """Update the settings for this WikiPage.
+        """Update the settings for this :class:`.WikiPage`.
 
-        :param listed: (boolean) Show this page on page list.
-        :param permlevel: (int) Who can edit this page? (0) use subreddit wiki
-            permissions, (1) only approved wiki contributors for this page may edit (see
-            :meth:`.WikiPageModeration.add`), (2) only mods may edit and view
+        :param listed: Show this page on page list.
+        :param permlevel: Who can edit this page? ``0`` use subreddit wiki permissions,
+            ``1`` only approved wiki contributors for this page may edit (see
+            :meth:`.WikiPageModeration.add`), ``2`` only mods may edit and view.
         :param other_settings: Additional keyword arguments to pass.
 
         :returns: The updated WikiPage settings.
 
-        To set the wikipage ``praw_test`` in ``r/test`` to mod only and disable it from
+        To set the wikipage ``praw_test`` in r/test to mod only and disable it from
         showing in the page list, try:
 
         .. code-block:: python
@@ -175,14 +175,9 @@ class WikiPageModeration:
 
 
 class WikiPage(RedditBase):
-    """An individual WikiPage object.
+    """An individual :class:`.WikiPage` object.
 
-    **Typical Attributes**
-
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor is this list necessarily complete.
+    .. include:: ../../typical_attributes.rst
 
     ================= =================================================================
     Attribute         Description
@@ -192,10 +187,10 @@ class WikiPage(RedditBase):
     ``may_revise``    A ``bool`` representing whether or not the authenticated user may
                       edit the wiki page.
     ``name``          The name of the wiki page.
-    ``revision_by``   The :class:`~.Redditor` who authored this revision of the wiki
+    ``revision_by``   The :class:`.Redditor` who authored this revision of the wiki
                       page.
     ``revision_date`` The time of this revision, in `Unix Time`_.
-    ``subreddit``     The :class:`~.Subreddit` this wiki page belongs to.
+    ``subreddit``     The :class:`.Subreddit` this wiki page belongs to.
     ================= =================================================================
 
     .. _unix time: https://en.wikipedia.org/wiki/Unix_time
@@ -206,9 +201,10 @@ class WikiPage(RedditBase):
 
     @staticmethod
     async def _revision_generator(
+        *,
+        generator_kwargs: Dict[str, Any],
         subreddit: "asyncpraw.models.Subreddit",
         url: str,
-        generator_kwargs: Dict[str, Any],
     ) -> AsyncGenerator[
         Dict[str, Optional[Union[Redditor, "WikiPage", str, int, bool]]], None
     ]:
@@ -247,7 +243,7 @@ class WikiPage(RedditBase):
         revision: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
     ):
-        """Construct an instance of the WikiPage object.
+        """Initialize a :class:`.WikiPage` instance.
 
         :param revision: A specific revision ID to fetch. By default, fetches the most
             recent revision.
@@ -279,7 +275,7 @@ class WikiPage(RedditBase):
     async def _fetch_data(self):
         name, fields, params = self._fetch_info()
         path = API_PATH[name].format(**fields)
-        return await self._reddit.request("GET", path, params)
+        return await self._reddit.request(method="GET", params=params, path=path)
 
     async def _fetch(self):
         data = await self._fetch_data()
@@ -291,17 +287,18 @@ class WikiPage(RedditBase):
         self.__dict__.update(data)
         self._fetched = True
 
+    @_deprecate_args("content", "reason")
     async def edit(
-        self, content: str, reason: Optional[str] = None, **other_settings: Any
+        self, *, content: str, reason: Optional[str] = None, **other_settings: Any
     ):
-        """Edit this WikiPage's contents.
+        """Edit this wiki page's contents.
 
         :param content: The updated Markdown content of the page.
-        :param reason: (Optional) The reason for the revision.
+        :param reason: The reason for the revision.
         :param other_settings: Additional keyword arguments to pass.
 
-        For example, to replace the first wiki page of ``r/test`` with the phrase ``test
-        wiki page``:
+        For example, to replace the first wiki page of r/test with the phrase ``"test
+        wiki page"``:
 
         .. code-block:: python
 
@@ -312,8 +309,7 @@ class WikiPage(RedditBase):
         """
         other_settings.update({"content": content, "page": self.name, "reason": reason})
         await self._reddit.post(
-            API_PATH["wiki_edit"].format(subreddit=self.subreddit),
-            data=other_settings,
+            API_PATH["wiki_edit"].format(subreddit=self.subreddit), data=other_settings
         )
 
     def discussions(
@@ -326,8 +322,7 @@ class WikiPage(RedditBase):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        To view the titles of discussions of the page ``"praw_test"`` in ``r/test``,
-        try:
+        To view the titles of discussions of the page ``"praw_test"`` in r/test, try:
 
         .. code-block:: python
 
@@ -348,13 +343,13 @@ class WikiPage(RedditBase):
     async def revision(self, revision: str):
         """Return a specific version of this page by revision ID.
 
-        To view revision ``[ID]`` of ``"praw_test"`` in ``r/test``:
+        To view revision ``"1234abc"`` of ``"praw_test"`` in r/test:
 
         .. code-block:: python
 
             subreddit = await reddit.subreddit("test")
             page = await subreddit.wiki.get_page("praw_test", fetch=False)
-            revision = await page.revision("[ID]")
+            revision = await page.revision("1234abc")
 
         """
         page = WikiPage(self.subreddit._reddit, self.subreddit, self.name, revision)
@@ -369,7 +364,7 @@ class WikiPage(RedditBase):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        To view the wiki revisions for ``"praw_test"`` in ``r/test`` try:
+        To view the wiki revisions for ``"praw_test"`` in r/test try:
 
         .. code-block:: python
 
@@ -391,4 +386,6 @@ class WikiPage(RedditBase):
         url = API_PATH["wiki_page_revisions"].format(
             subreddit=self.subreddit, page=self.name
         )
-        return self._revision_generator(self.subreddit, url, generator_kwargs)
+        return self._revision_generator(
+            generator_kwargs=generator_kwargs, subreddit=self.subreddit, url=url
+        )
