@@ -22,7 +22,7 @@ class Objector:
 
         :param data: The dict to be converted.
 
-        :returns: An instance of :class:`~.RedditAPIException`, or ``None`` if ``data``
+        :returns: An instance of :class:`.RedditAPIException`, or ``None`` if ``data``
             doesn't fit this model.
 
         """
@@ -50,24 +50,60 @@ class Objector:
     def __init__(
         self, reddit: "asyncpraw.Reddit", parsers: Optional[Dict[str, Any]] = None
     ):
-        """Initialize an Objector instance.
+        """Initialize an :class:`.Objector` instance.
 
-        :param reddit: An instance of :class:`~.Reddit`.
+        :param reddit: An instance of :class:`.Reddit`.
 
         """
         self.parsers = {} if parsers is None else parsers
         self._reddit = reddit
 
     def _objectify_dict(self, data):
-        """Create RedditBase objects from dicts.
+        """Create :class:`.RedditBase` objects from dicts.
 
         :param data: The structured data, assumed to be a dict.
 
-        :returns: An instance of :class:`~.RedditBase`.
+        :returns: An instance of :class:`.RedditBase`.
 
         """
-        if {"conversation", "messages", "modActions"}.issubset(data):
+        if {"messages", "modActions"}.issubset(data) and {
+            "conversations",
+            "conversation",
+        }.intersection(data):
+            data.update(
+                data.pop("conversation")
+                if "conversation" in data
+                else data.pop("conversations")
+            )
+            parser: "asyncpraw.models.ModmailConversation" = self.parsers[
+                "ModmailConversation"
+            ]
+            parser._convert_conversation_objects(data, self._reddit)
+        elif {"messages", "modActions"}.issubset(data):
             parser = self.parsers["ModmailConversation"]
+        elif {"conversationIds", "conversations", "messages"}.issubset(data):
+            conversations = []
+            temp_data = {
+                thing_type: data.pop(thing_type, {})
+                for thing_type in ["messages", "modActions"]
+            }
+            for conversation_id in data["conversationIds"]:
+                conversation_data = {
+                    **data["conversations"][conversation_id],
+                    "messages": [],
+                    "modActions": [],
+                }
+                for object_id in conversation_data["objIds"]:
+                    conversation_data[object_id["key"]].append(
+                        self._objectify_dict(
+                            temp_data[object_id["key"]].pop(object_id["id"])
+                        )
+                    )
+                conversations.append(conversation_data)
+            data["conversations"] = conversations
+            del temp_data
+            data = snake_case_keys(data)
+            parser = self.parsers["ModmailConversations-list"]
         elif {"actionTypeId", "author", "date"}.issubset(data):
             # Modmail mod action
             data = snake_case_keys(data)
@@ -155,6 +191,25 @@ class Objector:
                     draft["modified"] / 1000
                 ).astimezone()
             parser = self.parsers["DraftList"]
+        elif {"mod_action_data", "user_note_data"}.issubset(data):
+            redditor_parser = self.parsers[self._reddit.config.kinds["redditor"]]
+            subreddit_parser = self.parsers[self._reddit.config.kinds["subreddit"]]
+            data["moderator"] = redditor_parser(self._reddit, data["operator"])
+            data["subreddit"] = subreddit_parser(self._reddit, data["subreddit"])
+            data["user"] = redditor_parser(self._reddit, data["user"])
+            # move these sub dict values into the main dict for simplicity
+            data.update(data["mod_action_data"])
+            del data["mod_action_data"]
+            data.update(data["user_note_data"])
+            del data["user_note_data"]
+            parser = self.parsers["mod_note"]
+        elif (
+            "created" in data
+            and isinstance(data["created"], dict)
+            and {"mod_action_data", "user_note_data"}.issubset(data["created"])
+        ):
+            data = data["created"]
+            return self._objectify_dict(data)
         else:
             if "user" in data:
                 parser = self.parsers[self._reddit.config.kinds["redditor"]]
@@ -165,11 +220,11 @@ class Objector:
     def objectify(
         self, data: Optional[Union[Dict[str, Any], List[Any], bool]]
     ) -> Optional[Union[RedditBase, Dict[str, Any], List[Any], bool]]:
-        """Create RedditBase objects from data.
+        """Create :class:`.RedditBase` objects from data.
 
         :param data: The structured data.
 
-        :returns: An instance of :class:`~.RedditBase`, or ``None`` if given ``data`` is
+        :returns: An instance of :class:`.RedditBase`, or ``None`` if given ``data`` is
             ``None``.
 
         """
