@@ -61,7 +61,7 @@ class TestComment(IntegrationTest):
         self.reddit.read_only = False
         with self.use_cassette():
             comment = Comment(self.reddit, "fwxxs5d")
-            await comment.edit("New text")
+            await comment.edit(body="New text")
             assert comment.body == "New text"
 
     async def test_enable_inbox_replies(self):
@@ -123,6 +123,15 @@ class TestComment(IntegrationTest):
             comment = await self.async_next(self.reddit.inbox.comment_replies())
             await comment.mark_unread()
 
+    async def test_notes(self):
+        self.reddit.read_only = False
+        with self.use_cassette():
+            comment = await self.reddit.comment("id4adsw")
+            note = await comment.mod.create_note(label="HELPFUL_USER", note="test note")
+            notes = await self.async_list(comment.mod.author_notes())
+            assert note in notes
+            assert notes[notes.index(note)].user == comment.author
+
     async def test_parent__comment(self):
         comment = Comment(self.reddit, "cklhv0f")
         with self.use_cassette():
@@ -247,7 +256,7 @@ class TestComment(IntegrationTest):
     async def test_save(self):
         self.reddit.read_only = False
         with self.use_cassette():
-            await Comment(self.reddit, "fx19hsi").save("foo")
+            await Comment(self.reddit, "fx19hsi").save(category="foo")
 
     async def test_unsave(self):
         self.reddit.read_only = False
@@ -345,7 +354,9 @@ class TestCommentModeration(IntegrationTest):
             await mod.remove()
             message = "message"
             res = [
-                await mod.send_removal_message(message, "title", type)
+                await mod.send_removal_message(
+                    message=message, title="title", type=type
+                )
                 for type in ("public", "private", "private_exposed")
             ]
             assert isinstance(res[0], Comment)
@@ -361,7 +372,9 @@ class TestCommentModeration(IntegrationTest):
             comment = await self.reddit.comment("fx1jgsp")
             await comment.mod.remove()
             with pytest.raises(RedditAPIException) as excinfo:
-                await comment.mod.send_removal_message("message", "a" * 51)
+                await comment.mod.send_removal_message(
+                    message="message", title="a" * 51
+                )
             exception = excinfo.value
             assert "title" == exception.field
             assert "TOO_LONG" == exception.error_type
