@@ -46,9 +46,7 @@ class TestEmoji(IntegrationTest):
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
             emoji = await subreddit.emoji.get_emoji("test_png")
             await emoji.update(
-                mod_flair_only=False,
-                post_flair_allowed=True,
-                user_flair_allowed=True,
+                mod_flair_only=False, post_flair_allowed=True, user_flair_allowed=True
             )
 
     @mock.patch("asyncio.sleep", return_value=None)
@@ -79,8 +77,8 @@ class TestSubredditEmoji(IntegrationTest):
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
             for extension in ["jpg", "png"]:
                 emoji = await subreddit.emoji.add(
-                    f"test_{extension}",
-                    f"tests/integration/files/test.{extension}",
+                    name=f"test_{extension}",
+                    image_path=f"tests/integration/files/test.{extension}",
                 )
                 assert isinstance(emoji, Emoji)
 
@@ -91,8 +89,8 @@ class TestSubredditEmoji(IntegrationTest):
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
             for extension in ["jpg", "png"]:
                 emoji = await subreddit.emoji.add(
-                    f"test_{extension}",
-                    f"tests/integration/files/test.{extension}",
+                    name=f"test_{extension}",
+                    image_path=f"tests/integration/files/test.{extension}",
                     mod_flair_only=True,
                     post_flair_allowed=True,
                     user_flair_allowed=False,
