@@ -7,22 +7,22 @@ from ... import UnitTest
 
 
 class TestRemovalReason(UnitTest):
-    def test_equality(self):
+    def test_equality(self, reddit):
         reason1 = RemovalReason(
-            self.reddit, subreddit=Subreddit(self.reddit, display_name="a"), id="x"
+            reddit, subreddit=Subreddit(reddit, display_name="a"), id="x"
         )
         reason2 = RemovalReason(
-            self.reddit, subreddit=Subreddit(self.reddit, display_name="a"), id="2"
+            reddit, subreddit=Subreddit(reddit, display_name="a"), id="2"
         )
         reason3 = RemovalReason(
-            self.reddit, subreddit=Subreddit(self.reddit, display_name="b"), id="1"
+            reddit, subreddit=Subreddit(reddit, display_name="b"), id="1"
         )
         reason4 = RemovalReason(
-            self.reddit, subreddit=Subreddit(self.reddit, display_name="A"), id="x"
+            reddit, subreddit=Subreddit(reddit, display_name="A"), id="x"
         )
         reason5 = RemovalReason(
-            self.reddit,
-            subreddit=Subreddit(self.reddit, display_name="a"),
+            reddit,
+            subreddit=Subreddit(reddit, display_name="a"),
             reason_id="X",
         )
         assert reason1 == reason1
@@ -34,52 +34,48 @@ class TestRemovalReason(UnitTest):
         assert reason1 == reason4
         assert reason1 != reason5
 
-    def test_exception(self):
+    def test_exception(self, reddit):
+        with pytest.raises(ValueError):
+            RemovalReason(reddit, subreddit=Subreddit(reddit, display_name="a"))
         with pytest.raises(ValueError):
             RemovalReason(
-                self.reddit, subreddit=Subreddit(self.reddit, display_name="a")
-            )
-        with pytest.raises(ValueError):
-            RemovalReason(
-                self.reddit,
-                subreddit=Subreddit(self.reddit, display_name="a"),
+                reddit,
+                subreddit=Subreddit(reddit, display_name="a"),
                 id="test",
                 _data={},
             )
         with pytest.raises(ValueError):
-            RemovalReason(
-                self.reddit, subreddit=Subreddit(self.reddit, display_name="a"), id=""
-            )
+            RemovalReason(reddit, subreddit=Subreddit(reddit, display_name="a"), id="")
         with pytest.raises(ValueError):
             RemovalReason(
-                self.reddit,
-                subreddit=Subreddit(self.reddit, display_name="a"),
+                reddit,
+                subreddit=Subreddit(reddit, display_name="a"),
                 reason_id="",
             )
 
-    async def test__get(self):
-        subreddit = Subreddit(self.reddit, display_name="a")
+    async def test__get(self, reddit):
+        subreddit = Subreddit(reddit, display_name="a")
         removal_reason = await subreddit.mod.removal_reasons.get_reason(
             "a", fetch=False
         )
         assert isinstance(removal_reason, RemovalReason)
 
-    def test_hash(self):
+    def test_hash(self, reddit):
         reason1 = RemovalReason(
-            self.reddit, subreddit=Subreddit(self.reddit, display_name="a"), id="x"
+            reddit, subreddit=Subreddit(reddit, display_name="a"), id="x"
         )
         reason2 = RemovalReason(
-            self.reddit, subreddit=Subreddit(self.reddit, display_name="a"), id="2"
+            reddit, subreddit=Subreddit(reddit, display_name="a"), id="2"
         )
         reason3 = RemovalReason(
-            self.reddit, subreddit=Subreddit(self.reddit, display_name="b"), id="1"
+            reddit, subreddit=Subreddit(reddit, display_name="b"), id="1"
         )
         reason4 = RemovalReason(
-            self.reddit, subreddit=Subreddit(self.reddit, display_name="A"), id="x"
+            reddit, subreddit=Subreddit(reddit, display_name="A"), id="x"
         )
         reason5 = RemovalReason(
-            self.reddit,
-            subreddit=Subreddit(self.reddit, display_name="a"),
+            reddit,
+            subreddit=Subreddit(reddit, display_name="a"),
             reason_id="X",
         )
         assert hash(reason1) == hash(reason1)
@@ -90,20 +86,20 @@ class TestRemovalReason(UnitTest):
         assert hash(reason1) == hash(reason4)
         assert hash(reason1) != hash(reason5)
 
-    def test_repr(self):
+    def test_repr(self, reddit):
         reason = RemovalReason(
-            self.reddit, subreddit=Subreddit(self.reddit, display_name="a"), id="x"
+            reddit, subreddit=Subreddit(reddit, display_name="a"), id="x"
         )
         assert repr(reason) == "RemovalReason(id='x')"
 
-    def test_str(self):
+    def test_str(self, reddit):
         reason = RemovalReason(
-            self.reddit, subreddit=Subreddit(self.reddit, display_name="a"), id="x"
+            reddit, subreddit=Subreddit(reddit, display_name="a"), id="x"
         )
         assert str(reason) == "x"
 
 
 class TestSubredditRemovalReasons(UnitTest):
-    def test_repr(self):
-        sr = SubredditRemovalReasons(subreddit=Subreddit(self.reddit, display_name="a"))
+    def test_repr(self, reddit):
+        sr = SubredditRemovalReasons(subreddit=Subreddit(reddit, display_name="a"))
         assert repr(sr)  # assert it has some repr
