@@ -10,10 +10,10 @@ from ... import UnitTest
 
 
 class TestSubreddit(UnitTest):
-    def test_equality(self):
-        subreddit1 = Subreddit(self.reddit, _data={"display_name": "dummy1", "n": 1})
-        subreddit2 = Subreddit(self.reddit, _data={"display_name": "Dummy1", "n": 2})
-        subreddit3 = Subreddit(self.reddit, _data={"display_name": "dummy3", "n": 2})
+    def test_equality(self, reddit):
+        subreddit1 = Subreddit(reddit, _data={"display_name": "dummy1", "n": 1})
+        subreddit2 = Subreddit(reddit, _data={"display_name": "Dummy1", "n": 2})
+        subreddit3 = Subreddit(reddit, _data={"display_name": "dummy3", "n": 2})
         assert subreddit1 == subreddit1
         assert subreddit2 == subreddit2
         assert subreddit3 == subreddit3
@@ -23,29 +23,27 @@ class TestSubreddit(UnitTest):
         assert "dummy1" == subreddit1
         assert subreddit2 == "dummy1"
 
-    def test_construct_failure(self):
+    def test_construct_failure(self, reddit):
         message = "Either `display_name` or `_data` must be provided."
         with pytest.raises(TypeError) as excinfo:
-            Subreddit(self.reddit)
+            Subreddit(reddit)
         assert str(excinfo.value) == message
 
         with pytest.raises(TypeError) as excinfo:
-            Subreddit(self.reddit, "dummy", {"id": "dummy"})
+            Subreddit(reddit, "dummy", {"id": "dummy"})
         assert str(excinfo.value) == message
 
         with pytest.raises(ValueError):
-            Subreddit(self.reddit, "")
+            Subreddit(reddit, "")
 
-    def test_fullname(self):
-        subreddit = Subreddit(
-            self.reddit, _data={"display_name": "name", "id": "dummy"}
-        )
+    def test_fullname(self, reddit):
+        subreddit = Subreddit(reddit, _data={"display_name": "name", "id": "dummy"})
         assert subreddit.fullname == "t5_dummy"
 
-    def test_hash(self):
-        subreddit1 = Subreddit(self.reddit, _data={"display_name": "dummy1", "n": 1})
-        subreddit2 = Subreddit(self.reddit, _data={"display_name": "Dummy1", "n": 2})
-        subreddit3 = Subreddit(self.reddit, _data={"display_name": "dummy3", "n": 2})
+    def test_hash(self, reddit):
+        subreddit1 = Subreddit(reddit, _data={"display_name": "dummy1", "n": 1})
+        subreddit2 = Subreddit(reddit, _data={"display_name": "Dummy1", "n": 2})
+        subreddit3 = Subreddit(reddit, _data={"display_name": "dummy3", "n": 2})
         assert hash(subreddit1) == hash(subreddit1)
         assert hash(subreddit2) == hash(subreddit2)
         assert hash(subreddit3) == hash(subreddit3)
@@ -61,8 +59,10 @@ class TestSubreddit(UnitTest):
         return_value=("fake_media_url", "fake_websocket_url"),
     )
     @mock.patch("aiohttp.client.ClientSession.ws_connect")
-    async def test_invalid_media(self, connection_mock, _mock_upload_media, _mock_post):
-        self.reddit._core._requestor._http = aiohttp.ClientSession()
+    async def test_invalid_media(
+        self, connection_mock, _mock_upload_media, _mock_post, reddit
+    ):
+        reddit._core._requestor._http = aiohttp.ClientSession()
         recv_mock = MagicMock()
         recv_mock.receive_json = CoroutineMock(
             return_value={"payload": {}, "type": "failed"}
@@ -71,33 +71,64 @@ class TestSubreddit(UnitTest):
         context_manager.__aenter__.return_value = recv_mock
         connection_mock.return_value = context_manager
 
-        # websockets_mock().__aenter__.recv =
         with pytest.raises(MediaPostFailed):
-            await Subreddit(self.reddit, display_name="test").submit_image(
+            await Subreddit(reddit, display_name="test").submit_image(
                 "Test", "dummy path"
             )
-        await self.reddit._core._requestor._http.close()
+        await reddit._core._requestor._http.close()
 
-    def test_repr(self):
-        subreddit = Subreddit(self.reddit, display_name="name")
+    @mock.patch("asyncpraw.models.Subreddit._read_and_post_media")
+    @mock.patch(
+        "asyncpraw.Reddit.post",
+        return_value={
+            "json": {"data": {"websocket_url": ""}},
+            "args": {"action": "", "fields": []},
+        },
+    )
+    @mock.patch("aiohttp.client.ClientSession.ws_connect")
+    async def test_media_upload_500(
+        self, connection_mock, _mock_post, mock_method, reddit
+    ):
+        from aiohttp.http_exceptions import HttpProcessingError
+        from asyncprawcore.exceptions import ServerError
+
+        response = mock.Mock()
+        response.status = 201
+        response.raise_for_status = mock.Mock(
+            side_effect=HttpProcessingError(code=500, message="")
+        )
+        mock_method.return_value = response
+        with pytest.raises(ServerError):
+            await Subreddit(reddit, display_name="test").submit_image(
+                "Test", "/dev/null"
+            )
+
+    async def test_notes_delete__invalid_args(self):
+        with pytest.raises(TypeError) as excinfo:
+            await Subreddit(None, "SubTestBot1").mod.notes.delete(note_id="111")
+        assert excinfo.value.args[0] == (
+            "Either the `redditor` parameter must be provided or this method must be"
+            " called from a Redditor instance (e.g., `redditor.notes`)."
+        )
+
+    def test_repr(self, reddit):
+        subreddit = Subreddit(reddit, display_name="name")
         assert repr(subreddit) == "Subreddit(display_name='name')"
 
-    async def test_search__params_not_modified(self):
+    async def test_search__params_not_modified(self, reddit):
         params = {"dummy": "value"}
-        subreddit = Subreddit(self.reddit, display_name="name")
+        subreddit = Subreddit(reddit, display_name="name")
         generator = subreddit.search(None, params=params)
         assert generator.params["dummy"] == "value"
         assert params == {"dummy": "value"}
 
-    def test_str(self):
-        subreddit = Subreddit(
-            self.reddit, _data={"display_name": "name", "id": "dummy"}
-        )
+    def test_str(self, reddit):
+        subreddit = Subreddit(reddit, _data={"display_name": "name", "id": "dummy"})
         assert str(subreddit) == "name"
 
-    async def test_submit_failure(self):
+    async def test_submit_failure(self, reddit):
         message = "Either `selftext` or `url` must be provided."
-        subreddit = Subreddit(self.reddit, display_name="name")
+        subreddit = Subreddit(reddit, display_name="name")
 
         with pytest.raises(TypeError) as excinfo:
             await subreddit.submit("Cool title")
@@ -111,62 +142,63 @@ class TestSubreddit(UnitTest):
             await subreddit.submit("Cool title", selftext="", url="b")
         assert str(excinfo.value) == message
 
-    async def test_upload_banner_additional_image(self):
-        subreddit = Subreddit(self.reddit, display_name="name")
+    async def test_upload_banner_additional_image(self, reddit):
+        subreddit = Subreddit(reddit, display_name="name")
         with pytest.raises(ValueError):
             await subreddit.stylesheet.upload_banner_additional_image(
                 "dummy_path", align="asdf"
             )
 
-    async def test_submit_gallery__missing_path(self):
+    async def test_submit_gallery__missing_path(self, reddit):
         message = "'image_path' is required."
-        subreddit = Subreddit(self.reddit, display_name="name")
+        subreddit = Subreddit(reddit, display_name="name")
 
         with pytest.raises(TypeError) as excinfo:
             await subreddit.submit_gallery(
-                "Cool title", images=[{"caption": "caption"}, {"caption": "caption2"}]
+                "Cool title", [{"caption": "caption"}, {"caption": "caption2"}]
             )
         assert str(excinfo.value) == message
 
-    async def test_submit_gallery__invalid_path(self):
+    async def test_submit_gallery__invalid_path(self, reddit):
         message = "'invalid_image_path' is not a valid image path."
-        subreddit = Subreddit(self.reddit, display_name="name")
+        subreddit = Subreddit(reddit, display_name="name")
 
         with pytest.raises(TypeError) as excinfo:
             await subreddit.submit_gallery(
-                "Cool title", images=[{"image_path": "invalid_image_path"}]
+                "Cool title", [{"image_path": "invalid_image_path"}]
             )
         assert str(excinfo.value) == message
 
-    async def test_submit_gallery__too_long_caption(self):
+    async def test_submit_gallery__too_long_caption(self, reddit):
         message = "Caption must be 180 characters or less."
-        subreddit = Subreddit(self.reddit, display_name="name")
+        subreddit = Subreddit(reddit, display_name="name")
         caption = (
-            "wayyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy"
-            " too long caption"
+            "wayyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy"
+            "yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy"
+            "yyyyyyyyyyyyyyyy too long caption"
         )
         with pytest.raises(TypeError) as excinfo:
             await subreddit.submit_gallery(
-                "Cool title", images=[{"image_path": __file__, "caption": caption}]
+                "Cool title", [{"image_path": __file__, "caption": caption}]
             )
         assert str(excinfo.value) == message
 
-    async def test_submit_inline_media__invalid_path(self):
+    async def test_submit_inline_media__invalid_path(self, reddit):
         message = "'invalid_image_path' is not a valid file path."
-        subreddit = Subreddit(self.reddit, display_name="name")
+        subreddit = Subreddit(reddit, display_name="name")
         gif = InlineGif("invalid_image_path", "optional caption")
         image = InlineImage("invalid_image_path", "optional caption")
         video = InlineVideo("invalid_image_path", "optional caption")
         selftext = "Text with {gif1}, {image1}, and {video1} inline"
         media = {"gif1": gif, "image1": image, "video1": video}
         with pytest.raises(ValueError) as excinfo:
-            await subreddit.submit("title", selftext=selftext, inline_media=media)
+            await subreddit.submit("title", inline_media=media, selftext=selftext)
         assert str(excinfo.value) == message
 
 
 class TestSubredditFlair(UnitTest):
-    async def test_set(self):
-        subreddit = Subreddit(self.reddit, pytest.placeholders.test_subreddit)
+    async def test_set(self, reddit):
+        subreddit = Subreddit(reddit, pytest.placeholders.test_subreddit)
         with pytest.raises(TypeError):
             await subreddit.flair.set(
                 "a_redditor", css_class="myCSS", flair_template_id="gibberish"
@@ -174,28 +206,28 @@ class TestSubredditFlair(UnitTest):
 
 
 class TestSubredditFlairTemplates(UnitTest):
-    async def test_not_implemented(self):
+    async def test_not_implemented(self, reddit):
         with pytest.raises(NotImplementedError):
             await SubredditFlairTemplates(
-                Subreddit(self.reddit, pytest.placeholders.test_subreddit)
+                Subreddit(reddit, pytest.placeholders.test_subreddit)
             ).__aiter__()
 
 
 class TestSubredditWiki(UnitTest):
-    async def test__getitem(self):
-        subreddit = Subreddit(self.reddit, display_name="name")
+    async def test__getitem(self, reddit):
+        subreddit = Subreddit(reddit, display_name="name")
         wikipage = await subreddit.wiki.get_page("Foo", fetch=False)
         assert isinstance(wikipage, WikiPage)
         assert "foo" == wikipage.name
 
 
 class TestSubredditModmailConversationsStream(UnitTest):
-    async def test_conversation_stream_init(self):
-        submodstream = Subreddit(self.reddit, display_name="mod").mod.stream
+    async def test_conversation_stream_init(self, reddit):
+        submodstream = Subreddit(reddit, display_name="mod").mod.stream
         submodstream.modmail_conversations()
         assert submodstream.subreddit == "all"
 
-    async def test_conversation_stream_capilization(self):
-        submodstream = Subreddit(self.reddit, display_name="Mod").mod.stream
+    async def test_conversation_stream_capitalization(self, reddit):
+        submodstream = Subreddit(reddit, display_name="Mod").mod.stream
         submodstream.modmail_conversations()
         assert submodstream.subreddit == "all"
