@@ -1,8 +1,8 @@
 import os
 import sys
-from asynctest import mock
 
 import pytest
+from asynctest import mock
 
 from asyncpraw.config import Config
 from asyncpraw.exceptions import ClientException
@@ -41,6 +41,11 @@ class TestConfig:
                 else:
                     os.environ[env_name] = prev_environment[env_name]
 
+    def test_check_for_updates__false(self):
+        for value in [False, "False", "other"]:
+            config = Config("DEFAULT", check_for_updates=value)
+            assert config.check_for_updates is False
+
     def test_custom__extra_values_set(self):
         config = Config("DEFAULT", user1="foo", user2="bar")
         assert config.custom == {"user1": "foo", "user2": "bar"}
@@ -49,6 +54,11 @@ class TestConfig:
         config = Config("DEFAULT")
         assert config.custom == {}
 
+    def test_check_for_updates__true(self):
+        for value in [True, "1", "true", "YES", "on"]:
+            config = Config("DEFAULT", check_for_updates=value)
+            assert config.check_for_updates is True
+
     @mock.patch("configparser.ConfigParser")
     def test_load_ini_from_appdata(self, mock_config):
         self._assert_config_read("APPDATA", mock_config)
